
dialogId("disk-v-metrova", "font_big", "Look how much bigger than me it is. It is a three and a half meter floppy.")
dialogStr("Schau, sie ist viel grösser als ich. Es ist eine Dreieinhalb-Meter-Diskette.")


dialogId("disk-m-velka", "font_small", "That’s better. Big plan, big disk. That makes sense.")
dialogStr("Das ist besser. Grosser Plan, grosse Diskette. Das macht Sinn.")


dialogId("disk-v-nane", "font_big", "Suit yourself. I am curious how are you going to do it now.")
dialogStr("Viel Spass. Ich bin neugierig, wie du das jetzt machen willst.")

